@@ -1,4 +1,5 @@
-from eventlet.green import zmq
+from request_handling import zmq
+
 import json
 from uuid import uuid4
 import cgi
@@ -7,6 +8,7 @@ import logging
 import Cookie
 
 
+
 ###
 ### Request handling code
 ###
@@ -122,15 +124,25 @@ class Request(object):
 
     def get_arguments(self, name, strip=True):
         """Returns a list of the arguments with the given name. If the argument
-        is not present, returns an empty list. The returned values are always
-        unicode.
+        is not present, returns a None. The returned values are always unicode.
         """
-        values = self.arguments.get(name, [])
-        # Get rid of any weird control chars
-        values = [re.sub(r"[\x00-\x08\x0e-\x1f]", " ", x) for x in values]
-        values = [unicode(x) for x in values]
+        values = self.arguments.get(name, None)
+        if values is None:
+            return None
+
+        # Get the stripper ready
         if strip:
-            values = [x.strip() for x in values]
+            stripper = lambda v: v.strip()
+        else:
+            stripper = lambda v: v
+
+        def clean_value(v):
+            v = re.sub(r"[\x00-\x08\x0e-\x1f]", " ", v)
+            v = unicode(v)
+            v = stripper(v)
+            return v
+
+        values = [clean_value(v) for v in values]
         return values
 
     def get_argument(self, name, default=None, strip=True):
@@ -192,7 +204,7 @@ class Mongrel2Connection(object):
         internally.
         """
         header = "%s %d:%s," % (uuid, len(str(conn_id)), str(conn_id))
-        self.out_sock.send_unicode(header + ' ' + msg)        
+        self.out_sock.send(header + ' ' + to_bytes(msg))
 
     def reply(self, req, msg):
         """Does a reply based on the given Request object and message.
