@@ -227,6 +227,9 @@ class MessageHandler(object):
         """
         return self.render_error(-1)
 
+    def error(self, err):
+        return self.unsupported()
+
     def add_to_payload(self, key, value):
         """Upserts key-value pair into payload.
         """
@@ -245,7 +248,7 @@ class MessageHandler(object):
         status msg to the the relevant msg as defined in _response_codes.
         """
         if status_msg is None:
-            status_msg = self._response_codes[status_code]
+            status_msg = self._response_codes.get(status_code, str(status_code))
         if extra_txt:
             status_msg = '%s - %s' % (status_msg, extra_txt)
         self.add_to_payload(self._STATUS_CODE, status_code)
@@ -318,7 +321,7 @@ class MessageHandler(object):
                     return ''
             except Exception, e:
                 logging.error(e, exc_info=True)
-                rendered = self.unsupported()
+                rendered = self.error(e)
                 
             self._finished = True
             return rendered
@@ -341,6 +344,7 @@ class WebMessageHandler(MessageHandler):
         200: 'OK',
         400: 'Bad request',
         401: 'Authentication failed',
+        403: 'Forbidden',
         404: 'Not found',
         405: 'Method not allowed',
         500: 'Server error',
